==> dde-daemon_3.2.13.3.orig.tar.xz: dde-daemon-3.2.13.3/misc/ts/com.deepin.daemon.accounts.policy/policy_ms.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ms" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="com.deepin.daemon.accounts.change-own-user-data!message" line="0"/>
			<source>Authentication is required to change your own user data</source>
			<translation>Pengesahihan diperlukan untuk mengubah data pengguna anda sendiri</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.change-own-user-data!description" line="0"/>
			<source>Change your own user data</source>
			<translation>Ubah data pengguna anda sendiri</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.user-administration!message" line="0"/>
			<source>Authentication is required to change user data</source>
			<translation>Pengesahihan diperlukan untuk mengubah data pengguna</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.user-administration!description" line="0"/>
			<source>Manage user accounts</source>
			<translation>Urus akaun pengguna</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-auto-login!message" line="0"/>
			<source>Authentication is required to enable auto login</source>
			<translation>Pengesahihan diperlukan untuk membolehkan daftar masuk automatik</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-auto-login!description" line="0"/>
			<source>Enable Auto Login</source>
			<translation>Benarkan Auto Daftar Masuk</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-auto-login!message" line="0"/>
			<source>Authentication is required to disable auto login</source>
			<translation>Pengesahihan diperlukan untuk melumpuhkan daftar masuk automatik</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-auto-login!description" line="0"/>
			<source>Disable Auto Login</source>
			<translation>Lumpuhkan Auto Daftar Masuk</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-nopass-login!message" line="0"/>
			<source>Authentication is required to enable login without password</source>
			<translation>Pengesahihan diperlukan untuk membolehkan daftar masuk tanpa kata laluan</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-nopass-login!description" line="0"/>
			<source>Enable Login without password</source>
			<translation>Benarkan Daftar masuk tanpa kata laluan</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-nopass-login!message" line="0"/>
			<source>Authentication is required to disable login without password</source>
			<translation>Pengesahihan diperlukan untuk melumpuhkan daftar masuk tanpa kata laluan</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-nopass-login!description" line="0"/>
			<source>Disable Login without password</source>
			<translation>Lumpuhkan Daftar masuk tanpa kata laluan</translation>
		</message>
	</context>
</TS>

==> dde-daemon_5.12.52.orig.tar.xz: dde-daemon-5.12.52/misc/ts/com.deepin.daemon.accounts.policy/policy_ms.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ms" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="com.deepin.daemon.accounts.change-own-user-data!message" line="0"/>
			<source>Authentication is required to change your own user data</source>
			<translation>Pengesahihan diperlukan untuk mengubah data pengguna anda sendiri</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.change-own-user-data!description" line="0"/>
			<source>Change your own user data</source>
			<translation>Ubah data pengguna anda sendiri</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.user-administration!message" line="0"/>
			<source>Authentication is required to change user data</source>
			<translation>Pengesahihan diperlukan untuk mengubah data pengguna</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.user-administration!description" line="0"/>
			<source>Manage user accounts</source>
			<translation>Urus akaun pengguna</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-auto-login!message" line="0"/>
			<source>Authentication is required to enable auto login</source>
			<translation>Pengesahihan diperlukan untuk membolehkan daftar masuk automatik</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-auto-login!description" line="0"/>
			<source>Enable Auto Login</source>
			<translation>Benarkan Daftar Masuk Automatik</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-auto-login!message" line="0"/>
			<source>Authentication is required to disable auto login</source>
			<translation>Pengesahihan diperlukan untuk melumpuhkan daftar masuk automatik</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-auto-login!description" line="0"/>
			<source>Disable Auto Login</source>
			<translation>Lumpuhkan Daftar Masuk Automatik</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-nopass-login!message" line="0"/>
			<source>Authentication is required to enable login without password</source>
			<translation>Pengesahihan diperlukan untuk membolehkan daftar masuk tanpa kata laluan</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-nopass-login!description" line="0"/>
			<source>Enable Login without password</source>
			<translation>Benarkan Daftar masuk tanpa kata laluan</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-nopass-login!message" line="0"/>
			<source>Authentication is required to disable login without password</source>
			<translation>Pengesahihan diperlukan untuk melumpuhkan daftar masuk tanpa kata laluan</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-nopass-login!description" line="0"/>
			<source>Disable Login without password</source>
			<translation>Lumpuhkan Daftar masuk tanpa kata laluan</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.set-keyboard-layout!message" line="0"/>
			<source>Authentication is required to set keyboard layout</source>
			<translation>Pengesahihan diperlukan untuk menetapkan bentangan papan kekunci</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.set-keyboard-layout!description" line="0"/>
			<source>Set keyboard layout</source>
			<translation>Tetapkan bentangan papan kekunci</translation>
		</message>
	</context>
</TS>
